@@ -470,6 +470,7 @@ IsSeekable(const AVFormatContext &format_context) noexcept
 #if LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(58, 6, 100)
 	return (format_context.ctx_flags & AVFMTCTX_UNSEEKABLE) != 0;
 #else
+	(void)format_context;
 	return false;
 #endif
 }
@@ -658,6 +659,8 @@ ffmpeg_scan_stream(InputStream &is, TagHandler &handler)
 	return FfmpegScanStream(*f, handler);
 }
 
+#if LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(58, 9, 100)
+
 static void
 ffmpeg_uri_decode(DecoderClient &client, const char *uri)
 {
@@ -689,6 +692,8 @@ ffmpeg_protocols() noexcept
 	return protocols;
 }
 
+#endif
+
 /**
  * A list of extensions found for the formats supported by ffmpeg.
  * This list is current as of 02-23-09; To find out if there are more
@@ -812,6 +817,8 @@ static const char *const ffmpeg_mime_types[] = {
 constexpr DecoderPlugin ffmpeg_decoder_plugin =
 	DecoderPlugin("ffmpeg", ffmpeg_decode, ffmpeg_scan_stream)
 	.WithInit(ffmpeg_init, ffmpeg_finish)
+#if LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(58, 9, 100)
 	.WithProtocols(ffmpeg_protocols, ffmpeg_uri_decode)
+#endif
 	.WithSuffixes(ffmpeg_suffixes)
 	.WithMimeTypes(ffmpeg_mime_types);
